<?php

/**
 * DNSthingy javascript helper.
 *
 * @category   apps
 * @package    gateway-management-community
 * @subpackage javascript
 * @author     DNSthingy <support@dnsthingy.com>
 * @copyright  2015 DNSthingy
 * @license    All rights reserved
 * @link       https://www.dnsthingy.com
 */

///////////////////////////////////////////////////////////////////////////////
// B O O T S T R A P
///////////////////////////////////////////////////////////////////////////////

$bootstrap = getenv('CLEAROS_BOOTSTRAP') ? getenv('CLEAROS_BOOTSTRAP') : '/usr/clearos/framework/shared';
require_once $bootstrap . '/bootstrap.php';

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

// Classes
//--------

use \clearos\apps\gateway_management\DNSthingy as DNSthingy;

clearos_load_library('gateway_management/DNSthingy');

$dnsthingy = new DNSthingy;

///////////////////////////////////////////////////////////////////////////////
// J A V A S C R I P T
///////////////////////////////////////////////////////////////////////////////

header('Content-Type:application/x-javascript');
?>

var dt_content_class;
var dt_ip;

$(document).ready(function() {
    setup_variables_by_version();

    // shouldn't be triggered on set up page, and must be enabled
    var el = $('#dt_dashboard_msg.enabled');
    if (el.length) {
        dt_dashboard_status();
    }

    var http_address = $('#http_address');

    http_address.on('change keyup paste', function() {
        dt_validate_http_address(http_address);
    });

    if (!http_address.val()) {
        dt_suggest_http_address(http_address);
    }
});

function setup_variables_by_version() {
    // ClearOS 6
    if ($('#dt_content .theme-infobox-text').length) {
        dt_content_class = '.theme-infobox-text';

    // ClearOS 7
    } else if ($('#dt_content .theme-infobox-content').length) {
        dt_content_class = '.theme-infobox-content';

    // Unknown. Style won't be right, but at least messages will display
    } else {
        dt_content_class = '';
    }
}

function dt_status_to_color(status) {
    var el = $('<p></p>').appendTo('body');
    var color = el.addClass('text-' + status).css('color');
    el.remove();
    return color;
}

function dt_dashboard_status() {
    $.ajax({
        url: '/app/gateway_management_community/ajax/dashboard',
        type: 'GET',
        success: function (data) {
            dt_msg(data.message, 'success');
        },
        error: function (error) {
            if (error.responseJSON && error.responseJSON.message) {
                dt_msg(error.responseJSON.message, 'danger');
            } else if (error.responseJSON && error.responseJSON.errors) {
                dt_msg('Error registering your account.', 'danger');
            } else {
                dt_msg('Error checking account status.', 'danger');
            }
        }
    });
}

function dt_msg(msg, status) {
    var el = $('#dt_dashboard_msg');

    var color = dt_status_to_color(status);
    el.html(msg).css('color', color);
}

function dt_validate_http_address(el) {
    var value = el.val();

    // abort if IP hasn't changed
    if (dt_ip === value)
        return;

    dt_ip = value;

    dt_http_address_msg('Checking IP...', 'muted', true);

    $.ajax({
        url: '/app/gateway_management_community/ajax/validate_ip/' + value,
        type: 'GET',
        success: function (data) {
            // make sure this isn't for a previously typed IP address
            if (dt_ip === data.ip) {
                // display message
                dt_http_address_msg(data.msg, data.status);
            }
        },
        error: function () {
            dt_http_address_msg('Unable to check IP.', 'danger');
        }
    });
}

function dt_suggest_http_address(el) {
    dt_http_address_msg('Searching for IP...', 'muted', true);
    $.ajax({
        url: '/app/gateway_management_community/ajax/suggest_ip',
        type: 'GET',
        success: function (data) {
            // async tasks can take a while, so check status again
            if (data.ip && !el.val()) {
                el.val(data.ip);
            }
            dt_http_address_msg(data.msg, data.status);
        },
        error: function () {
            dt_http_address_msg('Unable to suggest IP.', 'danger');
        }
    });
}

function dt_http_address_msg(msg, status, loading) {
    var error_id = 'http_address_error';
    var msg_box = $('#' + error_id);
    if (!msg_box.length) {
        $('#http_address').after('<div class="theme-validation-error" id="' + error_id + '"></div>');
        msg_box = $('#' + error_id);
    }

    if (loading) {
        msg = '<i class="fa fa-spin fa-spinner"></i> ' + msg;
    }

    var color = dt_status_to_color(status);
    msg_box.html(msg).css('color', color);
}
